@@ -6,7 +6,7 @@ import requests
 from requests.structures import CaseInsensitiveDict
 
 from bbcloud_python_sdk.Api.Exceptions import ParameterErrorException, MethodNotAllowedErrorException, \
-    NoResourcesException, ClientErrorException
+    NoResourcesException, ClientErrorException, UnauthorizedException, ServiceErrorException, PermissionDenied
 
 
 class Http():
@@ -138,12 +138,19 @@ class Response(object):
         self.response = response
         self.status = response.status_code
         self.headers = response.headers
+
+        if self.status >= 500:
+            raise ServiceErrorException(json.loads(response.content)['message'])
         if self.status == 422:
             raise ParameterErrorException(self.read())
         if self.status == 405:
             raise MethodNotAllowedErrorException(response.request.method, response.url)
         if self.status == 404:
             raise NoResourcesException(response.url)
+        if self.status == 401:
+            raise UnauthorizedException(self.response.content)
+        if self.status == 403:
+            raise PermissionDenied(self.response.content)
         if self.status == 400:
             raise ClientErrorException(json.loads(response.content)['message'])
 
