@@ -32,6 +32,11 @@ class Query(object):
         return self
 
     def where(self, *args):
+        if len(args) == 1:
+            if isinstance(args[0], dict):
+                for key in args[0]:
+                    self.where(key, args[0][key])
+
         if len(args) == 2:
             self._query = '%s%s=%s,' % (self._query, args[0], args[1])
 
